Option Compare Binary
Option Explicit On 
Option Strict On

Imports DxVBLibA
Imports System

''' <summary>
'''   Stellt grundlegende Funktionalitt zum Abspielen von Wavedateien ber die
'''   Visual Basic-Bibliothek fr DirectX 8 bereit.
''' </summary>
Public Class DxSound
    Private m_dx As New DirectX8
    Private m_ds As DirectSound8
    Private m_dsb As DirectSoundSecondaryBuffer8
    Private m_bdscr As New DSBUFFERDESC
    Private m_FileName As String
    Private m_Volume As Integer
    Private m_hWnd As System.IntPtr

    ''' <summary>
    '''   Erstellt eine neue Instanz von <c>DxSound</c>.
    ''' </summary>
    Public Sub New()
    End Sub

    ''' <summary>
    '''   Erstellt eine neue Instanz der Klasse und weist den Eigenschaften die in den Parametern
    '''   bergebenen Werte zu.
    ''' </summary>
    ''' <param name="hWnd">Fenster-Handle, an das die Instanz der Klasse gebunden werden soll.</param>
    ''' <param name="Volume">Lautstrke des Abspielvorgangs.</param>
    ''' <param name="FileName">Name der abzuspielenden Musikdatei.</param>
    Public Sub New(ByVal hWnd As IntPtr, ByVal Volume As Integer, ByVal FileName As String)
        Me.hWnd = hWnd
        Me.Volume = Volume
        Me.FileName = FileName
    End Sub

    ''' <summary>
    '''   Beendet den Abspielvorgang.
    ''' </summary>
    Public Sub [Stop]()
        If Not m_dsb Is Nothing Then
            m_dsb.Stop()
        End If
    End Sub

    ''' <summary>
    '''   Startet den Abspielvorgang.
    ''' </summary>
    ''' <exception cref="Exception">
    '''   Wird ausgelst, wenn ein Fehler beim Erstellen des Soundpuffers fr die in der
    '''   Eigenschaft <c>FileName</c> angegebene Datei auftritt.
    ''' </exception>
    Public Sub Play()
        m_ds = m_dx.DirectSoundCreate("")
        m_ds.SetCooperativeLevel(m_hWnd.ToInt32(), CONST_DSSCLFLAGS.DSSCL_NORMAL)
        m_bdscr.lFlags = CONST_DSBCAPSFLAGS.DSBCAPS_CTRLPAN Or CONST_DSBCAPSFLAGS.DSBCAPS_CTRLVOLUME Or CONST_DSBCAPSFLAGS.DSBCAPS_CTRLFREQUENCY
        Try
            m_dsb = m_ds.CreateSoundBufferFromFile(Me.FileName, m_bdscr)
        Catch
            Throw
        End Try
        m_dsb.SetVolume(Me.Volume)
        m_dsb.Play(CONST_DSBPLAYFLAGS.DSBPLAY_DEFAULT)
    End Sub

    ''' <summary>
    '''   Gibt den Namen der Musikdatei, die abgespielt werden soll, an oder gibt ihn zurck.
    ''' </summary>
    ''' <value>Name der abzuspielenden Musikdatei.</value>
    Public Property FileName() As String
        Get
            Return m_FileName
        End Get
        Set(ByVal Value As String)
            m_FileName = Value
        End Set
    End Property

    ''' <summary>
    '''   Gibt die Lautstrke, mit der die in der Eigenschaft <c>FileName</c> angegebene Musikdatei
    '''   abgespielt werden soll, an oder gibt sie zurck.
    ''' </summary>
    ''' <value>Lautstrke des Abspielvorgangs.</value>
    ''' <exception cref="Exception">
    '''   Wird ausgelst, wenn ein ungltiger Wert fr die Lautstrke angegeben wird.
    ''' </exception>
    Public Property Volume() As Integer
        Get
            Return m_Volume
        End Get
        Set(ByVal Value As Integer)
            If Value >= -10000 AndAlso Value <= 0 Then
                m_Volume = Value
            Else
                Throw New ArgumentException("Volume must be an Integer between -10,000 and 0.")
            End If
        End Set
    End Property

    ''' <summary>
    '''   Gibt das Fenster-Handle, an das die Instanz der Klasse gebunden werden soll, an oder
    '''   gibt es zurck.
    ''' </summary>
    ''' <value>Fenster-Handle, an das die Instanz der Klasse gebunden werden soll.</value>
    Public Property hWnd() As IntPtr
        Get
            Return m_hWnd
        End Get
        Set(ByVal Value As IntPtr)
            m_hWnd = Value
        End Set
    End Property
End Class